#
# spec file for package monitoring-plugins-nwc_health
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         realname check_nwc_health
Name:           monitoring-plugins-nwc_health
Version:        11.5.1
Release:        bp160.1.3
Summary:        This plugin checks the health of network components and interfaces
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://labs.consol.de/nagios/check_nwc_health/
#Git-Clone      https://github.com/lausser/check_nwc_health.git
Source:         %{realname}-%{version}.tar.gz
# https://raw.githubusercontent.com/lausser/check_nwc_health/master/check_nwc_health.php
Source1:        check_nwc_health.php
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  make
BuildRequires:  nagios-rpm-macros
Provides:       nagios-plugins-nwc_health = %{version}-%{release}
Obsoletes:      nagios-plugins-nwc_health < %{version}-%{release}
Requires:       perl-Nagios-Plugin
Requires:       perl-Net-SNMP
Requires:       perl(File::Slurp)
Requires:       perl(JSON)
Requires:       perl(JSON::XS)
BuildArch:      noarch

%description
This plugin checks the hardware health and various interface metrics of
network components like switches and routers.

%prep
%setup -q -n %{realname}-%{version}

%build
autoreconf -fiv
%configure \
	--libexecdir=%{nagios_plugindir} \
	--with-nagios-user=%{nagios_user} \
	--with-nagios-group=%{nagios_group} \
	--with-perl=%{_bindir}/perl \
	--with-degrees=celsius \
	--enable-perfdata \
	--enable-hwinfo
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{nagios_plugindir}
make DESTDIR=%{buildroot} install %{?_smp_mflags}
install -D -m644 %{SOURCE1} %{buildroot}/%{pnp4nagios_templatedir}/check_nwc_health.php

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog README TODO
%license COPYING
# avoid build dependency of nagios - own the dirs
%dir %{nagios_libdir}
%{nagios_plugindir}/
%dir %{pnp4nagios_datadir}
%dir %{pnp4nagios_templatedir}
%{pnp4nagios_templatedir}/check_nwc_health.php

%changelog
* Tue Sep 10 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 11.5.1:
  Changes since 11.0.1
  * add mode sdwan-control-vedge-count for Cisco Viptela devices.
  * update changelog, add files for a proper commit, fix cisco
    sdwan load unit.
  * add mode security-status for Palo Alto (checks age of the last
    sw update).
  * fix mem/cpu/hw modes for Cisco SDWAN (IOS) which do hot have
    the Viptela-Mib.
  * bugfix in CheckPoint FW1 where R81.20 showed invalid cpu metrics
  * bugfix in UCD-MIB Load, external thresholds override the
    internal error status.
  * implement --servertype generic_fritzbox.
  * add SkyHigh Secure Web Gateway (and INTEL-SERVER-BASEBOARD7-MIB)
  * fix the list-arp-cache json output.
  * fix the Arista tweak.
  * finalize Juniper.
  * tweak ARISTA-ENTITY-SENSOR-MIB.
  * add juniper temperature perfdata.
  * improve Juniper-Mib, add more models.
  * add mode ha-status for Palo Alto.
  * bugfix in IFMIB and etherstats (uninizialized values).
  * add json-output for list-arp-cache.
  * add perfdata for the mode interface-nat-rejects.
  * fix Makefile.am and git add the cisco and arista pm files which
    i had forgotten.
  * add mode interface-errdisabled (Cisco and Arista only).
  * require, not use Net::Ping for F5 checks.
  * drecksmacoctetbinaerschlonz.
  * add mode list-arp-cache.
  * detect Ivanti devices (formerly identifying themselves as Pulse
    Secure).
  * show vlans only on demand, --report short+vlan.
  * more runtime reduction for huawei, cpu and mem.
  * suppress output of empty vlans.
  * cache huawei entities to avoid hitting the device's snmp rate
    limit.
  * cache vlan configs.
  * show vlans with interface-status.
  * C9800 fix.
  * typo in --lookup vs. --lookback.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 11.0.1
  Changes since 10.12.1.8:
  * support new C9800 wlan controller.
  * new structure suitble for epn.
  * reduce amount of data in cisco fru.
  * bugfix in traffic thresholds, do not use warning/critical
    def. thresholds.
  * implement traffic thresholds for interface-usage, correctly
    calc the less-than perfdata thresholds.
* Mon Jun 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 10.12.1.8
  Changes since 10.9.1:
  * reduce runtime for HOST-RESOURCES-MIB disk and device tables.
  * don't walk cefcFRUPowerSupplyGroupTable, it's unused anyway.
  * PR 310/311 for Fortigte HW.
  * bugfix in bluecat productname detection.
  * update glplugin (another epn fix, ::pluginname, ::plugin).
  * bugfix in Huawei Wlan Controller (just a perl warning, not
    serious) these recent perl warnings appeared after i heavily
    used the embedded perl feature of mod-gearman. it is much
    more strict than running the plugin as a standalone process).
  * bugfix in Pulse Secure (just a perl warning, not serious).
  * bugfix in Huawei bgp modes (just a perl warning, not serious).
  * add a cluster-check for cisco sdwan.
  * reduced runtime and amount of transferred data for bgp-related
    checks.
  * reduce runtime in Huwaei accesspoint modes.
  * bugfix in Huawei hardware-health. Discard temperatures of
    2147483647 deg.
  * improve Huawei hardware-health.
  * add filters to sdwan-check (name=dstip,name2=localcolor).
  * bugfix in Cisco Envmon notfunctioning.
  * bugfix again, exists plus defined.
  * bugfix in CISCO-ENVMON-MIB temperature (catch "notPresent").
  * bugfix in Checkpoint Management-Status.
* Thu Feb 23 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 10.9.1
  * bugfix in Checkpoint Management-Status
- Update to version 10.9.0
  * bugfix in Versa Peersubsystem
- Update to version 10.8.0.3
  * prepare some cisco sdwan stuff
  tweak huawei Entity-Table snmp parameters
- Update to version 10.8.0.2
  * force interface-vlan-count-macs to cache vlans
- Update to version 10.8.0.1
  * fix an undef in interface-vlan-count-macs
- Update to version 10.8
  * add mode interface-vlan-count-macs
- Update to version 10.7.1
  * tune snmp maxreps for bgp
- Update to version 10.7
  * rewrite detection of Juniper
- Update to version 10.6.1
  * improves ios hardware checks
- Update to version 10.6
  * add support for Viptela
* Sun Dec 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.5
  * add a temporary check for Cisco Viptela SDWAN
  * add Huawei wlan controller (not finished yet)
  * improve arista power supply/cord status checks
  * fix an uninitialized value in Arista HW check
* Sun Sep 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.3
  * add mode check-rtt (cisco-rttmon-mib slas)
* Mon Jul 25 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.2.1
  * update glplugin, better get_table fallback handling
* Fri May  6 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.1.0.3
  * fix a pull-request. Und das war damit auch der letzte
    Pull-Request, den ich in meinem Leben angenommen habe.
  * use JSON::XS in Interface.pm to avoid misleading UNKNOWN error
    message
  * suppress unknown arista sensors which are not marked as faulty
* Thu Feb 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.1.0.1
  * suppress unknown arista sensors which are not marked as faulty
  * check filesystems in Arista (full Log/Core stops syslog and
    accounting)
  * accept disabled sensors
  * bugfix in arista power supply
* Tue Jan 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 10.0.0.2
  * bugfix in f5 ltm detail output
  * tweak barracuda hardware-health snmp parameters
* Wed Nov 24 2021 ro@suse.de
- add dependencies to perl-JSON, perl-JSON-XS, perl-File-Slurp
  to prevent errors
* Thu Nov 18 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.0
  * use json for temporary files
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 9.1
  * add Pulse Secure
  * update git with latest cisco license gedoens
* Tue Sep 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 9.0.1.1
  * remove broken line from Makefile.am
  * improve cisco license checks
  * add Versa Appliance, add HP Aruba
  * tweak barracuda snmp params for interface/route checks
  * improve Barracuda cluster-check
* Sun Jul  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.4
  * add bgp for huawei
* Mon Jun 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.3.3.2
  * bugfix in IOS cpu-load for very old models without
    CISCO-PROCESS-MIB.
  * bugfix in f5 memory-usage, correct negative values.
  * Add vpn sessions for Fortigate.
  * optimize etherlike and rmon walks.
  * save bgp peer local addresses and show them in the error case.
* Thu May  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.3.2.2
  * Blacklist storage device "junosprocfs" on JunOS (Juniper)
    devices PR #278
  * bugfix in f5 cpu-load, correct negative values
  * query LM-SENSORS-MIB only if it exists on Linux (it may hang
    even if not existing)
  * bugfix in CISCO-ENTITY-SENSOR-MIB. Scale values correctly.
* Wed Mar  3 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.3.1.1
  * bugfix in interface-stack-status (triggered when --name did
    not match)
* Sat Feb 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.3.1
  * add mode license-status for cisco
  * split Bluecat in AddressManager and DnsDhcpServer
  * do not use cpmCPUMemoryHCCommitted, except if you want mem
    usage > 100%%
  * check the memory of all members in a cisco stack only if
    there are > 1 members
  * check the memory of all members in a cisco stack
  * bugfix in Bluecat jvm
* Tue Jan 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.1
  * add Bluecat Address Manager
* Fri Jan 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 8.0.0.2
  * bugfix in HOST-RESOURCE-MIB memory (Arista triggered)
  * bugfix in CISCO-ENVMON-MIB, temperatures > 200
- Update to version 8.0.0.1
  * bugfix in arista bgp, mitigate admin down
* Wed Dec 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 8.0
  * broadcast traffic is now shown as percentage of the overall
    traffic (...broadcast_in) and percentage of the available
    bandwitdth (..._broadcast_usage_in).
  * errors and discards are now calculated as percentage of all
    received/sent packets.
  * TenGig-VRF-MPLS-Dingsbums without errors and discard metrics
    are no longer treated as StackSubs.
- Update to version 7.13
  * add Vormetric Appliance
- Update to version 7.12.2
  * add some exceptions to hrDeviceDiskStorage and hrDeviceNetwork
* Tue Sep  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.12.1.3
  * fix a bug in mode count-routes, update glplugin
* Mon Jul 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.12.1.2
  * 2020-07-13 7.12.1.2
  * improve output for connect-vips
- Update to version 7.12.1.1
  * bugfix in UCD-MIB swap
- Update to version 7.12.1
  * try to fallback to ucd if neither sysUptime nor sysDescr exist
* Thu Jun  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.12
  * add mode watch-vips and connect-vips for F5
  * check the number of nodes in a Fortigate cluster
* Fri May 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.11
  * add bgp4 modes for arista, use 2nd context for cisco bgp4
* Tue May 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.4.1
  * fix a typo
* Mon May 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.4
  * check increase of sessions for Cisco (detect freeze with
  - -mode vpn-sessions --criticalx sessions_per_sec=0.001:)
  * add AVM 7580
* Fri Mar 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.3
  * add mode vpn-sessions (IOS and ASA)
  * blacklist nfs-mounts in hrDeviceDiskStorage
  * fix HP Aruba checks, add nore from ENTITY-SENSOR-MIB
  * fix a bug in interface-etherstats for
    OLD-CISCO-INTERFACES-MIB
* Tue Jan 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.8
  * fix a bug in Cisco memory, for Cisco emulation mode of
    Bel VPN Gate
* Mon Jan 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.7
  * fix redundant argument in sprintf
  * fix operstatus in linuxlocal
* Thu Jan 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.6
  * fix a bug in verbose mode if --nosensors is used
* Sat Dec  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.5
  * update GLPlugin, reduce default maxrepetitions to 20
* Thu Dec  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.4
  * reduce maxrepetitions for f5 sysCpuTable and ifTables
* Wed Dec  4 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.3
  * add --nosensors which skips endless entSensor[Threshold]Table
    for Nexuses
* Mon Nov 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.2
  * fix a division by 0 for cisco reserved memory
* Tue Oct  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.1.1
  * fix a bug in cisco wlan accesspoint-modes (InetAddrType)
  * add session-usage for palo alto
  * update glplugin, more nexus hardware-health improvements
* Thu Aug 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.0.6
  * reduce runtime for nexus hardware-health
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.0.5
  * fix EIGRP filtering
* Mon Jul 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.0.4.1
  * fix a bug in fortigate ha-role
  * fix a bug in interface-uptime
* Sun Jul 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.0.3
  * fix a bug in interface-uptime
  * fix a bug in mode ha-role for Fortigate
* Tue Jun 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10.0.1
  * fix a bug in bgp/route modes for the non-standalone version
    (InetAddressMaker)
* Fri Jun 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.10
  * remove duplicate routes (ip-table + inet-table)
  * --report long+address shows ip addresses for interfaces
* Sun Jun 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.9.0.4
  * finish barracuda ha-role mode
* Fri Jun 14 2019 Martin Hauke <mardnh@gmx.de>
- Update to versio 7.9.0.3
  * detect f5 firmware versions 14+
* Thu Jun 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.9.0.2
  * fix routes. inetCidrRouteTable does not really replace
    ipCidrRouteTable
- Update to version  7.9.0.1
  * fallback to BGP4-MIB if CISCO-BGP4-MIB is incomplete
  * Update to version  7.9
  * add EIGRP
  * fix ASA user/connection/session-count
* Sun Jun  9 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.8
  * GLPlugin with better ip4/ip6 handling
  * Fix huawei subclasses
  * Interfaces --name filter expression can contain _adminup_ as a
    secondary filter
  * Route modes can handle v6
  * Use OSPFV3-MIB, support v6
  * Add CISCO-BGP4-MIB, support v6
* Fri Apr 26 2019 Martin Hauke <mardnh@gmx.de>
- Add perl-Net-SNMP to Requires
* Sun Apr 14 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.7
  * add Barracuda
  * add mode count-connections for F5
* Thu Apr  4 2019 David Liedke <liedke@rz.uni-mannheim.de>
- Update to version 7.6
  * add mode watch-ospf-neighbors
* Mon Mar 18 2019 lars@linux-schulserver.de - 7.5.0.1
- Update to version 7.5.0.1
  * remove adsl-line-mib
- Update check_nwc_health.php to version 1.1 to work with pnp 0.6.25
  and beyond
- use %%%%license macro where appropriate
- use new SPDX license description
* Mon Feb 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 7.5
  * add Draytek Vigor
  * add mode interface-security (cisco)
  * finish ha-status for cisco wlc
  * start ha for cisco wlc
  * improve paloalto uptime model string
  * improve ucd memory
  * fix cisco bgp for routers which do not export the proptietary mib, but bgp4
  * fix undefs for Huawei with older Mibs
  * fix fortigate sensors
  * detect more Huawei devices
  * use proprietary bgp mib for cisco (and add ipv6)
  * make ospd v6-ready
  * add servertpe generic_ucd
  * fix ciscoipsecflow fail timestamps
  * add modes ha-status/role for fortigate
  * update glplugin (CISCO-STACKWISE-MIB)
  * update glplugin (for go-worker)
  * better fortigate detection
* Sat Sep 29 2018 mardnh@gmx.de
- Update to version 7.3.0.2
  * update glplugin
- Update to version 7.3.0.1
  * re-enable Huawei CloudEngine support
- Update to version 7.3
  * update stack-status
  * add servertype hostresource
  * update cisco vpn-status
* Sat Aug 18 2018 mardnh@gmx.de
- Update to version 7.2.0.2
  * bugfix in interface-modes where –name3 found no match
  * bugfix in ios ha-status, ignore cable “failover” description
* Thu Aug  2 2018 mardnh@gmx.de
- Update to version 7.2
  * add packet forwarding engine metrics for juniper standby nodes
* Fri Jul 27 2018 mardnh@gmx.de
- Update to version 7.1
  * add custom thresholds for cisco ccm
  * detect fritzbox 7490
* Sat Jul 14 2018 mardnh@gmx.de
- Update to version 7.0.2
  * add interface-uptime
* Fri Jul  6 2018 mardnh@gmx.de
- Update to version 7.0.1.5
  * fix a bug in non-map FabOS memory
  * set thresholds to 100%% for cisco asa heapcache memory-usage
* Tue Jun 19 2018 mardnh@gmx.de
- Update to version 7.0.1.5
  * update glplugin (get_snmp_table_objects waja fix)
* Tue Jun 12 2018 mardnh@gmx.de
- Update to version 7.0.1.4
  * simplify the cisco memory exceptions
* Tue May  1 2018 mardnh@gmx.de
- Update to version 7.0.1.3
  * bugfix in cisco global shared memory > 9.3.2
  * fix a bug in link-aggregation-availability
  * fix a bug in cisco enhanced mempool mib and posixmem (thx sabedevops)
  * improve f5, add ha-role, check-config, count-connections
  * update GLPlugin
  * ignore free space of iso mounts in hostresource mib
  * fix a bug in hostresourcesmib memory calc. (arista eos)
  * update glplugn, add modes encode/decode, rfc3986
  * add bluecoat asg fix from Stefan Kublik
  * check the clock of checkpoint fw
  * fix a bug in checkpoint vpn-status
  * code improvements, fix hh3c entities
  * fix f5 versions
  * add interface-duplex
  * fix a bug in vsx-firewall1-fork
  * add checkpoint ha-status, fix checkpoint vpn-status
  * rewrite pretty_sysdesc
  * updateGLPlugin (remove session timeout)
  * implement pool-completeness for f5-gtm-pools (--role gtm)
  * ignore dummy filesystems in HOSTRESOURCEMIBS
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 6.4.1.6
  + get ospf table twice if a 2nd contect exists
- Update to version 6.4.1.5
  + update GLPlugin (use 2nd context for OSPF)
- Update to version 6.4.1.4
  + fix interface-stack-status, arista's ifStackTable was buggy
- Update to version 6.4.1.3
  + blacklist l3 routing card (and power supply) if a nexus is used as l2 switch
- Update to version 6.4.1.2
  + workaround for CSCuv18572
- Update to version 6.4.1.1
  + fix hostresourcemib, interface sit0 can be down by default
    (is disabled in Cisco UC)
- Update to version 6.4.1
  + add vpn-status for checkpoint
- Update to version 6.4.0.4
  + fix brocade aliasing in interface-status
- Update to version 6.4.0.3
  + fix brocade alias aliasing
- Update to version 6.4.0.2
  + update glplugin, sw-mib fix
- Update to version 6.4.0.1
  + replace empty ifAlias with swFCPortName for FabOS (Brocade) devices
  + merge pr #147, thanks arigaud. skip undef temperatured of foundry devices
  + implement eltex gear (pull request #144)
  + fix a perl-undef in Juniper BGP (pull request #143)
  + nsPowerDesc can be null (pullrequest #134)
* Tue Aug  8 2017 mardnh@gmx.de
- update to 6.3.0.8
  fix C3750 redundant power supplies
* Mon Aug  7 2017 mardnh@gmx.de
- update to 6.3.0.7
  + fix undefined thresholds in arista sensors
* Tue Jul 18 2017 mardnh@gmx.de
- update to 6.3.0.6
  + fix false positives in cisco ethernet service modules SM-ES3G-24-P
    allow mitigation of cisco disabled catalyst power supplies
* Wed Jul 12 2017 mardnh@gmx.de
- update to 6.3.0.5
  + allow mitigation of a subLayerDown stack
  + update GLPlugin (lcos-mib)
* Tue Jun 20 2017 mardnh@gmx.de
- update to 6.3.0.3
  + update GLPlugin (lcos-mib)
* Sat Jun 10 2017 mardnh@gmx.de
- update to 6.3.0.2
  + fix a bug in f5 member connections (Thanks Yannick Charton)
  + skip ifIndex in interface-stack-status (makes nexus crash)
* Thu Jun  8 2017 mardnh@gmx.de
- update to 6.3.0.1
  + update glplugin
* Fri Jun  2 2017 mardnh@gmx.de
- update to 6.3
  + update glplugin
  + add Lancom
* Sat May 20 2017 mardnh@gmx.de
- update to 6.2.2.3
  + workaround for ios 12.x and buggy ifstacktable
* Wed May 17 2017 mardnh@gmx.de
- update to 6.2.2.2
  + and fix list-interfaces...
  + fix --name for non-uinique indices
- update to  6.2.2
  + add an index to ifDescr which have no unique names
* Tue May 16 2017 mardnh@gmx.de
- update to 6.2.1.5
  + GLPlugin update
- update to 6.2.1.4
  GLPlugin update
* Wed May 10 2017 mardnh@gmx.de
- update to 6.2.1.3
  + fix a bug in interface-health
* Thu May  4 2017 mardnh@gmx.de
- update to 6.2.0.2
  + fix a bug in interface-health and 10GE ports.
* Tue May  2 2017 mardnh@gmx.de
- update to 6.2.0.1
  + use carrier if operstatus is unknown for linuxlocal interfaces
  + add dummy speed to linux virtio interfaces
* Tue Apr 18 2017 mardnh@gmx.de
- update to 6.2.0
  + add support for junox bgp with ipv6, thanks dupondje
  + fix a bug in bluecoat, allow warningx now
- update to 6.1.1
  + support Brocade Ironport and enhance FOUNDRY-SN-AGENT-MIB
* Sun Mar 19 2017 mardnh@gmx.de
- update to 6.0.1.3
  + fix uninitialized-bug
  + special treatment for counterless StackSub interfaces
  + Merge pull request #126 from ciscoqid/patch-1
  + remove steelhead prettyprint
  + cisco chassis check snmp tuning
  + fix cisco-envmon-mib
  + nxos hardware check snmp tuning
  + fix cisco wlan no-ap clustercheck
  + detect more f5 models
  + add f5 wide ip check
  + improve host-resource-mib
  + speedup interface checks
  + add interface-etherstats
  + add ha-status for juniper vsd members
  + customer release #12.2a
  + add mode interface-stack-status
  + add riverbed steelhead
  + bugfix in f5 output message
  + make f5 perfdata labels more consistent
  + checkpoint multicore. Thanks Peter Hanraets
  + fix pool checks for big-ip 12.x (thanks abzeidler)
  + fallback to ios if cisco wlc has no cpu/mem oids
  + bugfix in chassis-hardware-health delta of ports
  + bugfix in chassis-hardware-health duplicate fan output
  + fix cisco wlc ap admin status
  + detect more cisco wireless controllers
  + update GLPlugin (uptime)
  + detect checkpoint gaia
  + detect more hp procurve switches (J9624A etc. may need new
    firmware revision RA.16.02.0012, ROM RA.15.13)
  + /dev/md on Juniper srx is considered as procfs
  + fix performance labels for HOSTRESOURCESMIB dev filesystems
  + optimize uptime, no bulk for brocade sensors
  + bluecoat disk usage can be overridden with own thresholds
  + add JUNIPER-MIB
  + fix in cisco asr lsmpi memory
  + skip thresholds for dev filesystem in HOSTRESOURCESMIB
  + detect juniper pulse secure
  + juniper srx temperatures and leds
  + reverse usage/free in hostresourcemib memory-usage, so the
    samethresholds can be use for every kind of device
  + mv juniper-mib to glplugin
  + add etherstats
  + fix nexus sensor perfdata, metrics without thresh. were not shown
  + add smart-home-device-temperature, add Comet DECT
  + fix memory-usage for Catalyst L3 (which have empty
    CISCO-ENHANCED-MEMPOOL-MIB)
  + add arista
  + add cisco small business
  + add mode count-accesspoint-clients for cisco wlc
  + don't use | in interface-availability ascii output for notifications
  + update ucd-diskio, cumulus
  + update GLPlugin/Extraopts
* Tue Sep  6 2016 lars@linux-schulserver.de
- update to 5.7.1.3:
  + remove trailing Nul from Bintec memories
  + Bintec doesn't like bulk requests
  + repair a pull request.
  + update GLPlugin
* Sun May 29 2016 mardnh@gmx.de
- update to 5.7.0.3
  + bugfix in nortel hardware-checks.
  + Do not check UCDMIB swap when there is no swap
  + fix a typo in a filename
  + add Bintec Bibo (1202)
  + add Cisco ASA mode ha-role (including cluster-health check)
  + fix detection of Pulse Secure Gateways
  + more dhoffend pull requests (linux ucdmib memory, lmsensors)
  + add vrrp-modes
  + dhoffend pull requests (linux ucdmib, lsmpio bugfix, hsrp multiple roles)
  + add CISCO-STACKWISE-MIB
  + add processor index in cisco enhanced memory
  + Use 64bit-counters from cisco-enhanced-mempool-mib if available (cisco bug CSCuu46705)
  + Simplify interface code
  + bugfix in –ifspeed
  + add mode chassis-hardware-health (for cisco)
  + update checkpoint, use new mib
  + fallback if no cisco cpu index can be found
  + refactor interface-usage, bugfix in list-interfaces
  + bugfix in link-aggregation-availability thresholds
  + fix cisco bgp prefix count if no peers were found
  + small fix in interfaces, add flat_indices
  + bugfix in entity-sensor-mib
  + add glplugin submodule
  + pr #52 cisco-alarm-mib parse octets (Thanks dhoffend)
  + Fix IOS-XE which no longer support the ENVMON MIB. Use FRU MIB instead.
  + introduce new units (based on 1000 instead of 1024),
  will have an impact on interface perfdata thresholds
  + add Huawei CloudEngine
  + chomp Checkpoint HA state
  + Add CheckPoint Power Supply Check
  + detect CheckPoint IPSO (Thanks Claudio Kuenzler)
  + fix standalone version
  + add –mode interface-health to linux, solaris, windows
  + find more bluecoat models
  + add –mode interface-health
  + merge huawei h3c from lazyfrosch-hh3c-switches
  + output ifAlias in interface-modes (if it exists and != ifDescr)
  + add rapid-city-mib
  + add entity-mib for cisco asa
* Wed Dec 23 2015 mardnh@gmx.de
- update to 4.6.1
  + add --mode interface-health to linux, solaris, windows
  + find more bluecoat models
  + add --mode interface-health
  + merge huawei h3c from lazyfrosch-hh3c-switches
  + output ifAlias in interface-modes (if it exists and != ifDescr)
  + add rapid-city-mib
  + add entity-mib for cisco asa
* Fri Sep 25 2015 mardnh@gmx.de
- update to 4.3.1
  + add ha-role for Aruba
  + add Alcatel OmniAccess (Aruba)
  + GLPlugin update
  + pull request #36. bugfix in cisco asyncos keys (Thanks Frank Meischner)
  + pull request #25. cisco check-config more useful. (Thanks mhoogveld)
  + add Nortel S5-CHASSIS-MIB, works for 4526GTX
  + add OneAccess OneOS
  + add Solaris local interfaces
  + GLPlugin update
  + add --count-bgp-prefixes for cisco
  + --disable-standalone
  + add --watch-bgp-peers
  + add --reset for watch-bgp-peers
  + bugfix in f5-pool-checks, where oids are not available during a transition"
  + allow --name dest/cidr for mode count-routes
  + fix a bug in f5 member connection limit noSuchInstance
  + add mode count-routes (find mpls problems)
  + add mode count-bgp-peers
  + add --community2 (necessary if there are different ospf contexts)
  + raise max-repetitions for table-bulk-requests (large number of interfaces)
  + add LM-SENSOR-MIB
  + bugfix in thresholds of morphed performancedata
  + implement ospf and modes ospf-neighbor-status and list-ospf-neighbors
  + separate discards from errors in linuxlocal
  + combine pool-connections and pool-completion for f5
  + finish pool-complections
  + detect (not implement!) netgear
  + add mode pool-connections for f5
  + allow mitigation of admin down bgp peer
  + add morphperfdata
  + bugfix in GLPlugin (multiple --negate)
  + more trailing null cleanup. (Thanks Jörg Linge)
  + bugfix in interface-usage windows+snmp+trailing null in ifDescr. (Thanks Jörg Linge)
  + bugfix in interface-status and snmp-table-get (no more false 64bit interfaces)
  + shorten interface-output with report=short
  + fix a perl-bug in F5 (was introduced in 3.4.2)
  + fix lsmpi_io for cisco asr1000 (Thanks Andreas Schulz)
  + fix Fritz!Box upnp control url (Thanks Bernd)
  + use fallbacks to find fexes (cefexConfigTable may not be populated)
  + use cefexConfigTable for mode watch-fexes
  + bugfix in cisco nexus sensors (had undef perl warnings)
  + bugfix in bluecoat hardware (skip perfdata of missing psus)
  + add vpn-status for cisco asa
  + add windowslocal
  + unique names for cisco cpus pointing to the same physical entity
  + remove unnecessary use statement
  + finalize paloalto ha
  + make list-interfaces and update-cache faster
  + hide some debug printfs
  + add palo alto hardware, sensors, ha
  + make nexus cpu names unique
  + bugfix my-modes
  + add paloaltomib
  + add Clavister Firewall (Thanks Dirk Goetz)
  + fix GLPluginSNMP, all timeout-like errors are UNKNOWN
  + allow warningx/criticalx to override cisco sensor thresholds
  + bugfix in glplugin (tmp-file-paths wrong under epn) (Thanks Sven Nierlein)
  + bugfix in bgp error states (Thanks Matthias Gallinger)
  + bugfix in f5 pools (Thanks Sven Nierlein)
  + bugfix in interface-usage/ifspeed (Thanks Matthias Gallinger)
  + bugfix in glpluginsnmp (undef errors with loadbalacer index)
  + bugfix in glpluginsnmp / (fritzbox cpu undef-error)
  + bugfix in glplugin/uptime because of buggy snmpengineuptime
  + bugfix in glplugin/uptime thresholds
  + add a hack with --name2 which allows shortening of stupid interface names (make dmz1 from Adaptive Security Appliance 'dmz1' interface)
  + update GLPluginSNMP (timeout handling)
  + fix interfaces which seem to be 64bit but have no counters
  + bugfix in offline mode
  + update GLPlugin
  + update GLPluginSNMP
  + bugfix in ios memory criticalx/warningx thresholds
  + update GLPluginSNMP
  + improve interface-usage performance data
  + detect more brocade models
  + bugfix in interface-usage temp-files
  + jetzt langts mit der ridiseignerei
  + massive rewriting of the plugins structure and modules
  + repair malformed data returned by Net::SNMP
  + add interface-nat-rejects and interface-nat-session-count for IOS
  + add hardware-health for cisco asa
  + bugfix for old brocade devices and missing cpu/memory oids
  + bugfix in Cisco Call Manager
  + bugfix in IOS Memory for ASR 9000 image and reserved pool
  + bugfix in cisco wlc status
  + add hardware-health for cisco pix
  + add mode supportedmibs
  + last fallback alarm-mib for ios without envmon-mib
  + bugfix in timeticks for hp
  + bugfix in Nexus sensor thresholds (Thanks Marcel Fischer)
  + bugfix in snmp-bulk-gets, more secure fallbacks to get-next
  + bugfix in 64bit-interfaces
  + GLPlugin update & cleanup
  + get uptime from the FRAMEWORK-MIB to prevent rollovers
  + add another cisco unified communication model
  + handle a missing brocade fabric watch license in cpu-load & memory-usage
  + add CISCO-ENHANCED-MEMPOOL-MIB
- fix source url
* Wed Jul 30 2014 lars@linux-schulserver.de
- Renamed package to monitoring-plugins-nwc_health
* Fri Apr  4 2014 mardnh@gmx.de
- initial package
